==> open-xchange-mobile-api-facade_1.0.3.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.3/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/weakforce/WeakforceWrapperAuthenticationService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.weakforce;

import com.openexchange.mobile.api.facade.auth.AuthenticationService;
import com.openexchange.mobile.api.facade.auth.LoginCredentials;
import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
import com.openexchange.mobile.api.facade.weakforce.models.AllowResponse;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

@RequiredArgsConstructor
@Slf4j
public class WeakforceWrapperAuthenticationService implements AuthenticationService {

    private final HostConfiguration configuration;

    private final WeakforceService weakforceService;

    private final AuthenticationService wrappedService;

    @Override
    public SessionData authenticate(LoginCredentials credentials) {
        boolean loginSuccessful = false;
        boolean policyReject = false;
        try {
            AllowResponse response = callWeakforceAllow(credentials);
            policyReject = response != null && response.isRejected();
            SessionData sessionData = null;
            if (!policyReject) {
                sessionData = wrappedService.authenticate(credentials);
                loginSuccessful = true;
            }
            return sessionData;
        } catch (ApiFacadeException e) {
            loginSuccessful = false;
            throw e;
        } finally {
            callWeakforceReport(credentials, loginSuccessful, policyReject);
        }
    }

    private AllowResponse callWeakforceAllow(LoginCredentials credentials) {
        AllowResponse allowResponse = null;
        try {
            allowResponse = weakforceService.allow(configuration, credentials);
            if (allowResponse.isDelayed()) {
                sleep(allowResponse.getSecondsToDelay());
            }
        } catch (ApiFacadeException e) {
            log.error("Failed to call weakforce.allow");
        }
        return allowResponse;
    }

    private void callWeakforceReport(LoginCredentials credentials, boolean loginSuccessful, boolean policyReject) {
        try {
            weakforceService.report(configuration, credentials, loginSuccessful, policyReject);
        } catch (ApiFacadeException e) {
            log.error("Failed to call weakforce.report");
        }
    }

    @Override
    public void logout(SessionData sessionData) {
        wrappedService.logout(sessionData);
    }

    private void sleep(int secondsToSleep) {
        try {
            log.info(String.format("Sleeping for %d seconds", secondsToSleep));
            Thread.sleep(secondsToSleep * 1000);
        } catch (InterruptedException e) {
            log.error(String.format("Failed to sleep for %d seconds", secondsToSleep), e);
        }
    }

}

==> open-xchange-mobile-api-facade_1.4.5.orig.tar.bz2: open-xchange-mobile-api-facade-1.4.5/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/weakforce/WeakforceWrapperAuthenticationService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.weakforce;

import com.openexchange.mobile.api.facade.auth.AuthenticationService;
import com.openexchange.mobile.api.facade.auth.LoginCredentials;
import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
import com.openexchange.mobile.api.facade.endpoints.requests.LogoutRequestBody;
import com.openexchange.mobile.api.facade.exceptions.ApiFacadeException;
import com.openexchange.mobile.api.facade.weakforce.models.AllowResponse;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

@RequiredArgsConstructor
@Slf4j
public class WeakforceWrapperAuthenticationService implements AuthenticationService {

    private final HostConfiguration configuration;

    private final WeakforceService weakforceService;

    private final AuthenticationService wrappedService;

    @Override
    public SessionData authenticate(LoginCredentials credentials) {
        boolean loginSuccessful = false;
        boolean policyReject = false;
        try {
            AllowResponse response = callWeakforceAllow(credentials);
            policyReject = response != null && response.isRejected();
            SessionData sessionData = null;
            if (!policyReject) {
                sessionData = wrappedService.authenticate(credentials);
                loginSuccessful = true;
            }
            return sessionData;
        } catch (ApiFacadeException e) {
            loginSuccessful = false;
            throw e;
        } finally {
            callWeakforceReport(credentials, loginSuccessful, policyReject);
        }
    }

    private AllowResponse callWeakforceAllow(LoginCredentials credentials) {
        AllowResponse allowResponse = null;
        try {
            allowResponse = weakforceService.allow(configuration, credentials);
            if (allowResponse.isDelayed()) {
                sleep(allowResponse.getSecondsToDelay());
            }
        } catch (ApiFacadeException e) {
            log.error("Failed to call weakforce.allow");
        }
        return allowResponse;
    }

    private void callWeakforceReport(LoginCredentials credentials, boolean loginSuccessful, boolean policyReject) {
        try {
            weakforceService.report(configuration, credentials, loginSuccessful, policyReject);
        } catch (ApiFacadeException e) {
            log.error("Failed to call weakforce.report");
        }
    }

    @Override
    public void logout(SessionData sessionData, LogoutRequestBody requestBody) {
        wrappedService.logout(sessionData, requestBody);
    }

    private void sleep(int secondsToSleep) {
        try {
            log.info(String.format("Sleeping for %d seconds", secondsToSleep));
            Thread.sleep(secondsToSleep * 1000);
        } catch (InterruptedException e) {
            log.error(String.format("Failed to sleep for %d seconds", secondsToSleep), e);
        }
    }

}
